"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const AccountRestrictionAddressValueBuilder_1 = require("./AccountRestrictionAddressValueBuilder");
const AccountRestrictionMosaicValueBuilder_1 = require("./AccountRestrictionMosaicValueBuilder");
const AccountRestrictionTransactionTypeValueBuilder_1 = require("./AccountRestrictionTransactionTypeValueBuilder");
const ExpandedAccountRestrictionFlagsDto_1 = require("./ExpandedAccountRestrictionFlagsDto");
const GeneratorUtils_1 = require("./GeneratorUtils");
class AccountRestrictionsInfoBuilder {
    constructor(restrictions1, restrictions2, restrictions3, restrictions4, restrictions5, restrictions6, restrictions7, restrictions8) {
        if ((restrictions1 && restrictions2 && restrictions3 && restrictions4 && restrictions5 && restrictions6 && restrictions7 && restrictions8) || (!restrictions1 && !restrictions2 && !restrictions3 && !restrictions4 && !restrictions5 && !restrictions6 && !restrictions7 && !restrictions8)) {
            throw new Error('Invalid conditional parameters');
        }
        this.restrictions1 = restrictions1;
        this.restrictions2 = restrictions2;
        this.restrictions3 = restrictions3;
        this.restrictions4 = restrictions4;
        this.restrictions5 = restrictions5;
        this.restrictions6 = restrictions6;
        this.restrictions7 = restrictions7;
        this.restrictions8 = restrictions8;
        if (restrictions1) {
            this.restrictionFlags = ExpandedAccountRestrictionFlagsDto_1.ExpandedAccountRestrictionFlagsDto.ADDRESS;
        }
        else if (restrictions2) {
            this.restrictionFlags = ExpandedAccountRestrictionFlagsDto_1.ExpandedAccountRestrictionFlagsDto.ADDRESS_OUTGOING;
        }
        else if (restrictions3) {
            this.restrictionFlags = ExpandedAccountRestrictionFlagsDto_1.ExpandedAccountRestrictionFlagsDto.ADDRESS_BLOCK;
        }
        else if (restrictions4) {
            this.restrictionFlags = ExpandedAccountRestrictionFlagsDto_1.ExpandedAccountRestrictionFlagsDto.ADDRESS_OUTGOING_BLOCK;
        }
        else if (restrictions5) {
            this.restrictionFlags = ExpandedAccountRestrictionFlagsDto_1.ExpandedAccountRestrictionFlagsDto.MOSAIC_ID;
        }
        else if (restrictions6) {
            this.restrictionFlags = ExpandedAccountRestrictionFlagsDto_1.ExpandedAccountRestrictionFlagsDto.MOSAIC_ID_BLOCK;
        }
        else if (restrictions7) {
            this.restrictionFlags = ExpandedAccountRestrictionFlagsDto_1.ExpandedAccountRestrictionFlagsDto.TRANSACTION_TYPE_OUTGOING;
        }
        else {
            this.restrictionFlags = ExpandedAccountRestrictionFlagsDto_1.ExpandedAccountRestrictionFlagsDto.TRANSACTION_TYPE_OUTGOING_BLOCK;
        }
    }
    static loadFromBinary(payload) {
        const byteArray = Array.from(payload);
        const restrictionFlags = GeneratorUtils_1.GeneratorUtils.bufferToUint(GeneratorUtils_1.GeneratorUtils.getBytes(Uint8Array.from(byteArray), 2));
        byteArray.splice(0, 2);
        const restrictionFlagsConditionBytes = Uint8Array.from(byteArray.slice(0, 1));
        byteArray.splice(0, 1);
        let restrictions1;
        if (restrictionFlags === ExpandedAccountRestrictionFlagsDto_1.ExpandedAccountRestrictionFlagsDto.ADDRESS) {
            restrictions1 = AccountRestrictionAddressValueBuilder_1.AccountRestrictionAddressValueBuilder.loadFromBinary(restrictionFlagsConditionBytes);
        }
        let restrictions2;
        if (restrictionFlags === ExpandedAccountRestrictionFlagsDto_1.ExpandedAccountRestrictionFlagsDto.ADDRESS_OUTGOING) {
            restrictions2 = AccountRestrictionAddressValueBuilder_1.AccountRestrictionAddressValueBuilder.loadFromBinary(restrictionFlagsConditionBytes);
        }
        let restrictions3;
        if (restrictionFlags === ExpandedAccountRestrictionFlagsDto_1.ExpandedAccountRestrictionFlagsDto.ADDRESS_BLOCK) {
            restrictions3 = AccountRestrictionAddressValueBuilder_1.AccountRestrictionAddressValueBuilder.loadFromBinary(restrictionFlagsConditionBytes);
        }
        let restrictions4;
        if (restrictionFlags === ExpandedAccountRestrictionFlagsDto_1.ExpandedAccountRestrictionFlagsDto.ADDRESS_OUTGOING_BLOCK) {
            restrictions4 = AccountRestrictionAddressValueBuilder_1.AccountRestrictionAddressValueBuilder.loadFromBinary(restrictionFlagsConditionBytes);
        }
        let restrictions5;
        if (restrictionFlags === ExpandedAccountRestrictionFlagsDto_1.ExpandedAccountRestrictionFlagsDto.MOSAIC_ID) {
            restrictions5 = AccountRestrictionMosaicValueBuilder_1.AccountRestrictionMosaicValueBuilder.loadFromBinary(restrictionFlagsConditionBytes);
        }
        let restrictions6;
        if (restrictionFlags === ExpandedAccountRestrictionFlagsDto_1.ExpandedAccountRestrictionFlagsDto.MOSAIC_ID_BLOCK) {
            restrictions6 = AccountRestrictionMosaicValueBuilder_1.AccountRestrictionMosaicValueBuilder.loadFromBinary(restrictionFlagsConditionBytes);
        }
        let restrictions7;
        if (restrictionFlags === ExpandedAccountRestrictionFlagsDto_1.ExpandedAccountRestrictionFlagsDto.TRANSACTION_TYPE_OUTGOING) {
            restrictions7 = AccountRestrictionTransactionTypeValueBuilder_1.AccountRestrictionTransactionTypeValueBuilder.loadFromBinary(restrictionFlagsConditionBytes);
        }
        let restrictions8;
        if (restrictionFlags === ExpandedAccountRestrictionFlagsDto_1.ExpandedAccountRestrictionFlagsDto.TRANSACTION_TYPE_OUTGOING_BLOCK) {
            restrictions8 = AccountRestrictionTransactionTypeValueBuilder_1.AccountRestrictionTransactionTypeValueBuilder.loadFromBinary(restrictionFlagsConditionBytes);
        }
        return new AccountRestrictionsInfoBuilder(restrictions1, restrictions2, restrictions3, restrictions4, restrictions5, restrictions6, restrictions7, restrictions8);
    }
    getRestrictionFlags() {
        return this.restrictionFlags;
    }
    getRestrictions1() {
        if (this.restrictionFlags !== ExpandedAccountRestrictionFlagsDto_1.ExpandedAccountRestrictionFlagsDto.ADDRESS) {
            throw new Error('restrictionFlags is not set to ADDRESS.');
        }
        return this.restrictions1;
    }
    getRestrictions2() {
        if (this.restrictionFlags !== ExpandedAccountRestrictionFlagsDto_1.ExpandedAccountRestrictionFlagsDto.ADDRESS_OUTGOING) {
            throw new Error('restrictionFlags is not set to ADDRESS_OUTGOING.');
        }
        return this.restrictions2;
    }
    getRestrictions3() {
        if (this.restrictionFlags !== ExpandedAccountRestrictionFlagsDto_1.ExpandedAccountRestrictionFlagsDto.ADDRESS_BLOCK) {
            throw new Error('restrictionFlags is not set to ADDRESS_BLOCK.');
        }
        return this.restrictions3;
    }
    getRestrictions4() {
        if (this.restrictionFlags !== ExpandedAccountRestrictionFlagsDto_1.ExpandedAccountRestrictionFlagsDto.ADDRESS_OUTGOING_BLOCK) {
            throw new Error('restrictionFlags is not set to ADDRESS_OUTGOING_BLOCK.');
        }
        return this.restrictions4;
    }
    getRestrictions5() {
        if (this.restrictionFlags !== ExpandedAccountRestrictionFlagsDto_1.ExpandedAccountRestrictionFlagsDto.MOSAIC_ID) {
            throw new Error('restrictionFlags is not set to MOSAIC_ID.');
        }
        return this.restrictions5;
    }
    getRestrictions6() {
        if (this.restrictionFlags !== ExpandedAccountRestrictionFlagsDto_1.ExpandedAccountRestrictionFlagsDto.MOSAIC_ID_BLOCK) {
            throw new Error('restrictionFlags is not set to MOSAIC_ID_BLOCK.');
        }
        return this.restrictions6;
    }
    getRestrictions7() {
        if (this.restrictionFlags !== ExpandedAccountRestrictionFlagsDto_1.ExpandedAccountRestrictionFlagsDto.TRANSACTION_TYPE_OUTGOING) {
            throw new Error('restrictionFlags is not set to TRANSACTION_TYPE_OUTGOING.');
        }
        return this.restrictions7;
    }
    getRestrictions8() {
        if (this.restrictionFlags !== ExpandedAccountRestrictionFlagsDto_1.ExpandedAccountRestrictionFlagsDto.TRANSACTION_TYPE_OUTGOING_BLOCK) {
            throw new Error('restrictionFlags is not set to TRANSACTION_TYPE_OUTGOING_BLOCK.');
        }
        return this.restrictions8;
    }
    getSize() {
        let size = 0;
        size += 2;
        if (this.restrictionFlags === ExpandedAccountRestrictionFlagsDto_1.ExpandedAccountRestrictionFlagsDto.ADDRESS) {
            size += this.restrictions1.getSize();
        }
        if (this.restrictionFlags === ExpandedAccountRestrictionFlagsDto_1.ExpandedAccountRestrictionFlagsDto.ADDRESS_OUTGOING) {
            size += this.restrictions2.getSize();
        }
        if (this.restrictionFlags === ExpandedAccountRestrictionFlagsDto_1.ExpandedAccountRestrictionFlagsDto.ADDRESS_BLOCK) {
            size += this.restrictions3.getSize();
        }
        if (this.restrictionFlags === ExpandedAccountRestrictionFlagsDto_1.ExpandedAccountRestrictionFlagsDto.ADDRESS_OUTGOING_BLOCK) {
            size += this.restrictions4.getSize();
        }
        if (this.restrictionFlags === ExpandedAccountRestrictionFlagsDto_1.ExpandedAccountRestrictionFlagsDto.MOSAIC_ID) {
            size += this.restrictions5.getSize();
        }
        if (this.restrictionFlags === ExpandedAccountRestrictionFlagsDto_1.ExpandedAccountRestrictionFlagsDto.MOSAIC_ID_BLOCK) {
            size += this.restrictions6.getSize();
        }
        if (this.restrictionFlags === ExpandedAccountRestrictionFlagsDto_1.ExpandedAccountRestrictionFlagsDto.TRANSACTION_TYPE_OUTGOING) {
            size += this.restrictions7.getSize();
        }
        if (this.restrictionFlags === ExpandedAccountRestrictionFlagsDto_1.ExpandedAccountRestrictionFlagsDto.TRANSACTION_TYPE_OUTGOING_BLOCK) {
            size += this.restrictions8.getSize();
        }
        return size;
    }
    serialize() {
        let newArray = Uint8Array.from([]);
        const restrictionFlagsBytes = GeneratorUtils_1.GeneratorUtils.uintToBuffer(this.getRestrictionFlags(), 2);
        newArray = GeneratorUtils_1.GeneratorUtils.concatTypedArrays(newArray, restrictionFlagsBytes);
        if (this.restrictionFlags === ExpandedAccountRestrictionFlagsDto_1.ExpandedAccountRestrictionFlagsDto.ADDRESS) {
            const restrictions1Bytes = this.restrictions1.serialize();
            newArray = GeneratorUtils_1.GeneratorUtils.concatTypedArrays(newArray, restrictions1Bytes);
        }
        if (this.restrictionFlags === ExpandedAccountRestrictionFlagsDto_1.ExpandedAccountRestrictionFlagsDto.ADDRESS_OUTGOING) {
            const restrictions2Bytes = this.restrictions2.serialize();
            newArray = GeneratorUtils_1.GeneratorUtils.concatTypedArrays(newArray, restrictions2Bytes);
        }
        if (this.restrictionFlags === ExpandedAccountRestrictionFlagsDto_1.ExpandedAccountRestrictionFlagsDto.ADDRESS_BLOCK) {
            const restrictions3Bytes = this.restrictions3.serialize();
            newArray = GeneratorUtils_1.GeneratorUtils.concatTypedArrays(newArray, restrictions3Bytes);
        }
        if (this.restrictionFlags === ExpandedAccountRestrictionFlagsDto_1.ExpandedAccountRestrictionFlagsDto.ADDRESS_OUTGOING_BLOCK) {
            const restrictions4Bytes = this.restrictions4.serialize();
            newArray = GeneratorUtils_1.GeneratorUtils.concatTypedArrays(newArray, restrictions4Bytes);
        }
        if (this.restrictionFlags === ExpandedAccountRestrictionFlagsDto_1.ExpandedAccountRestrictionFlagsDto.MOSAIC_ID) {
            const restrictions5Bytes = this.restrictions5.serialize();
            newArray = GeneratorUtils_1.GeneratorUtils.concatTypedArrays(newArray, restrictions5Bytes);
        }
        if (this.restrictionFlags === ExpandedAccountRestrictionFlagsDto_1.ExpandedAccountRestrictionFlagsDto.MOSAIC_ID_BLOCK) {
            const restrictions6Bytes = this.restrictions6.serialize();
            newArray = GeneratorUtils_1.GeneratorUtils.concatTypedArrays(newArray, restrictions6Bytes);
        }
        if (this.restrictionFlags === ExpandedAccountRestrictionFlagsDto_1.ExpandedAccountRestrictionFlagsDto.TRANSACTION_TYPE_OUTGOING) {
            const restrictions7Bytes = this.restrictions7.serialize();
            newArray = GeneratorUtils_1.GeneratorUtils.concatTypedArrays(newArray, restrictions7Bytes);
        }
        if (this.restrictionFlags === ExpandedAccountRestrictionFlagsDto_1.ExpandedAccountRestrictionFlagsDto.TRANSACTION_TYPE_OUTGOING_BLOCK) {
            const restrictions8Bytes = this.restrictions8.serialize();
            newArray = GeneratorUtils_1.GeneratorUtils.concatTypedArrays(newArray, restrictions8Bytes);
        }
        return newArray;
    }
}
exports.AccountRestrictionsInfoBuilder = AccountRestrictionsInfoBuilder;
//# sourceMappingURL=AccountRestrictionsInfoBuilder.js.map